import { PropType } from 'vue';
import { ElFormInstance } from '../../ele-app/el';
import { EleModalProps } from '../../ele-app/plus';
import { Columns, DataItem, SpanMethod, SummaryMethod, TreeProps } from '../../ele-data-table/types';
import { TableLocale, ExportDataType, BeforeExport, Datasource, FetchFunction, ColItem, TableExportParams } from '../types';

declare const _default: import('vue').DefineComponent<{
    /** 表格国际化 */
    locale: {
        type: PropType<TableLocale>;
        required: true;
    };
    /** 缓存本地的名称 */
    cacheKey: StringConstructor;
    /** 弹窗参数 */
    modalProps: PropType<EleModalProps>;
    /** 列数据 */
    columns: PropType<Columns>;
    /** 表格选中数据 */
    selections: PropType<DataItem[]>;
    /** 表格当前页数据 */
    pageData: PropType<DataItem[]>;
    /** 表格全部数据 */
    datasource: PropType<Datasource>;
    /** 单元格合并行列方法 */
    spanMethod: PropType<SpanMethod>;
    /** 表格是否有表头 */
    tableHeader: BooleanConstructor;
    /** 是否显示合计行 */
    showSummary: BooleanConstructor;
    /** 合计行文本 */
    sumText: StringConstructor;
    /** 合计行自定义方法 */
    summaryMethod: PropType<SummaryMethod>;
    /** 序号列起始索引 */
    pageIndex: NumberConstructor;
    /** 树表字段名 */
    treeProps: PropType<TreeProps>;
    /** 表格请求数据方法 */
    fetch: PropType<FetchFunction>;
    /** 默认文件名 */
    defaultFileName: {
        type: StringConstructor;
        default: string;
    };
    /** 默认数据类型 */
    defaultDataType: {
        type: PropType<ExportDataType>;
        default: string;
    };
    /** 默认是否勾选表尾 */
    defaultShowFooter: {
        type: BooleanConstructor;
        default: boolean;
    };
    /** 默认是否勾选层级序号 */
    defaultShowTreeIndex: BooleanConstructor;
    /** 导出前的钩子函数 */
    beforeExport: PropType<BeforeExport>;
}, {
    visible: import('vue').Ref<boolean>;
    loading: import('vue').Ref<boolean>;
    formRef: import('vue').Ref<ElFormInstance>;
    form: {
        fileName: string;
    };
    fileNameRules: Partial<import('element-plus').FormItemRule>;
    dataType: import('vue').Ref<ExportDataType>;
    colItems: import('vue').Ref<{
        uid: string;
        label?: string | undefined;
        checked?: boolean | undefined;
        fixed?: (boolean | string) | undefined;
        children?: any[] | undefined;
        type?: string | undefined;
        width?: (number | string) | undefined;
    }[]>;
    isCheckAll: import('vue').Ref<boolean>;
    isIndeterminate: import('vue').Ref<boolean>;
    showHeader: import('vue').Ref<boolean>;
    showFooter: import('vue').Ref<boolean>;
    showTreeIndex: import('vue').Ref<boolean>;
    treeIndexDisabled: import('vue').Ref<boolean>;
    openModal: () => void;
    closeModal: () => void;
    handleExport: () => void;
    handleCheckedChange: (item?: ColItem, checked?: boolean, type?: string) => void;
    handleSortChange: (items: ColItem[], parent?: ColItem) => void;
    handleColWidthChange: (item: ColItem, width?: string) => void;
    handleCheckAllChange: (checked: boolean) => void;
    handleReset: () => void;
    handleTreeIndexChange: (checked?: boolean | string | number) => void;
    exportData: (params?: TableExportParams) => void;
}, unknown, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, string, import('vue').PublicProps, Readonly<import('vue').ExtractPropTypes<{
    /** 表格国际化 */
    locale: {
        type: PropType<TableLocale>;
        required: true;
    };
    /** 缓存本地的名称 */
    cacheKey: StringConstructor;
    /** 弹窗参数 */
    modalProps: PropType<EleModalProps>;
    /** 列数据 */
    columns: PropType<Columns>;
    /** 表格选中数据 */
    selections: PropType<DataItem[]>;
    /** 表格当前页数据 */
    pageData: PropType<DataItem[]>;
    /** 表格全部数据 */
    datasource: PropType<Datasource>;
    /** 单元格合并行列方法 */
    spanMethod: PropType<SpanMethod>;
    /** 表格是否有表头 */
    tableHeader: BooleanConstructor;
    /** 是否显示合计行 */
    showSummary: BooleanConstructor;
    /** 合计行文本 */
    sumText: StringConstructor;
    /** 合计行自定义方法 */
    summaryMethod: PropType<SummaryMethod>;
    /** 序号列起始索引 */
    pageIndex: NumberConstructor;
    /** 树表字段名 */
    treeProps: PropType<TreeProps>;
    /** 表格请求数据方法 */
    fetch: PropType<FetchFunction>;
    /** 默认文件名 */
    defaultFileName: {
        type: StringConstructor;
        default: string;
    };
    /** 默认数据类型 */
    defaultDataType: {
        type: PropType<ExportDataType>;
        default: string;
    };
    /** 默认是否勾选表尾 */
    defaultShowFooter: {
        type: BooleanConstructor;
        default: boolean;
    };
    /** 默认是否勾选层级序号 */
    defaultShowTreeIndex: BooleanConstructor;
    /** 导出前的钩子函数 */
    beforeExport: PropType<BeforeExport>;
}>>, {
    showSummary: boolean;
    tableHeader: boolean;
    defaultDataType: ExportDataType;
    defaultShowFooter: boolean;
    defaultShowTreeIndex: boolean;
    defaultFileName: string;
}, {}>;
export default _default;
